##parameters=member_id
#$Id: getMemberEmail.py 26351 2005-09-01 10:03:40Z lregebro $
""" Returns the mail of a given user

This script will be usefull in custom member directories such as LDAP
while using the CPSDirectory with different schemas as the default
CPS ones.
"""

if member_id:
    membership = context.portal_membership
    return membership.getEmailFromUsername(member_id)

return None
